#!/usr/bin/env bash

# makegallery.sh - builds a simple 'gallery' from a collection of images
# Copyright (C) 2004 Brett Parker <iDunno@sommitrealweird.co.uk>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
# 
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
# 
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

set -f

VERSION="0.9.2"

if [[ -z $TITLE ]]; then 
	TITLE="Photo Gallery"
fi

if [[ -z $CONVERTTOOL ]]; then
	CONVERTTOOL="/usr/bin/convert"
fi

if [[ -z $FINDCOMMAND ]]; then
	FINDCOMMAND=/usr/bin/find
fi

if [[ -z $XARGSCOMMAND ]]; then
	XARGSCOMMAND=/usr/bin/xargs
fi

if [[ -z $ECHOCOMMAND ]]; then
	ECHOCOMMAND=/bin/echo
fi

if [[ -z $SORTCOMMAND ]]; then
	SORTCOMMAND=/usr/bin/sort
fi

if [[ -z $IDENTIFYCOMMAND ]]; then
	IDENTIFYCOMMAND=/usr/bin/identify
fi

if [[ -z $WIDTH ]]; then
	WIDTH=100
fi

if [[ -z $IMAGEEXTENSIONS ]]; then
	IMAGEEXTENSIONS="jpeg jpg gif png";
fi

FINDIMAGESOPTIONS=""

for imageext in $IMAGEEXTENSIONS; do
	FINDIMAGESOPTIONS=$FINDIMAGESOPTIONS' -o -type f -maxdepth 1 -iname '*.$imageext' -print0'
done

FINDIMAGESOPTIONS=${FINDIMAGESOPTIONS## -o }

usage() {
	cat <<END
Usage:
  $0 [--help|--version|<path to images>]

    --help
        displays this help screen
    --version
        displays the version and exits
	
END
}

version() {
	cat <<END
Version: $VERSION
END
}

if [[ -z $1 ]]; then
	echo "No path given"
	usage
	exit 1
fi

if [[ "$1" == "--help" || "$1" == "-h" ]]; then
	usage
	exit 0
fi

if [[ "$1" == "--version" || "$1" == "-v" ]]; then
	version
	exit 0
fi

if [[ ! -d $1 ]]; then
	echo "$1 is not a directory"
	usage
	exit 2
fi

cd "$1"

if ( ! $FINDCOMMAND . $FINDIMAGESOPTIONS > /dev/null 2>/dev/null ); then
	echo "$1 does not contain any images. Quitting."
	exit 4
fi

if [ ! -d icons ]; then
	mkdir icons
else
	echo "$1 already contains an icons folder, stopping"
	exit 3
fi

$FINDCOMMAND . $FINDIMAGESOPTIONS | $XARGSCOMMAND -0 --replace $CONVERTTOOL -resize $WIDTH '{}' 'icons/{}'

cat <<END > index.html
<?xml version="1.0"?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en">
<head>
	<title>${TITLE}</title>
	<link rel="stylesheet" href="style.css" type="text/css" />
</head>
<body>
END


$FINDCOMMAND . $FINDIMAGESOPTIONS | $XARGSCOMMAND -0 --replace $ECHOCOMMAND {} |$SORTCOMMAND -g | sed -e 's#^./\(.*\)$#<div class="thumbnail"><a href="\1"><img src="icons/\1" /></a></div>#' >> index.html

cat <<END >> index.html
</body>
</html>
END


cd icons

for imageext in $IMAGEEXTENSIONS; do
	if ( ls "*.$imageext" > /dev/null 2>/dev/null ); then
		TEMPMAX=$($IDENTIFYCOMMAND *.$imageext | grep "Geometry:" | sed -r 's#^.*Geometry:.*?[0-9]+x([0-9]+)\+.*$#\1#' | $SORTCOMMAND -g -r | head -n 1)
		if [[ $TEMPMAX -gt $MAXHEIGHT ]]; then
			MAXHEIGHT=$TEMPMAX
		fi
	fi
done

cd ..


cat <<END > style.css
body {
        background: white;
        color: black;
        font-family: sans-serif;
        font-size: 12pt;
}

div.thumbnail {
        float: left;
        padding: 20px;
        border: 0px;
        width: ${WIDTH}px;
        height: ${MAXHEIGHT}px;
}

a {
        border: 0px;
}

img {
        border: 0px;
}
END

